Each line in a PLUMED input file defines and action. The actions in the input file communicate through the passing of values.
In early versions of PLUMED these values were scalars.  However, from PLUMED 2.10 onwards you can pass values that are scalars, 
vectors, matrices or functions on grids.  

The tools in this module all you to construct or manipulate matrices. Please note that you can also use the tools in the 
[adjmat](module_adjmat.md) module to construct matrices that might be used in the input to the actions in this module.


